.. _functional_connectivity:

============================================
Functional connectivity and resting state
============================================

Functional connectivity and resting-state data can be studied in many
different way. Nilearn provides tools to construct "connectomes" that
capture functional interactions between regions, or to extract regions
and networks, via resting-state networks or parcellations.

|

.. toctree::

   functional_connectomes.rst
   connectome_extraction.rst
   resting_state_networks.rst
   region_extraction.rst
   parcellating.rst
